pyslink
========

|pyversions| |status|

Soft link a file/directory with python site-packages directory.
Useful during development.

Installation via pip::

    pip install pyslink

Soft link a package::

    pyslink path/to/main/module


.. |pyversions| image:: https://img.shields.io/pypi/pyversions/pyslink.svg
  :target: https://pypi.python.org/pypi/pyslink
.. |status| image:: https://img.shields.io/pypi/status/pyslink.svg
  :target: https://pypi.python.org/pypi/pyslink
